@@ -12,7 +12,7 @@
 #include "calendarutils.h"
 #include "utils.h"
 
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 #include <KCalendarCore/Incidence>
 
 #include "calendarsupport_debug.h"
@@ -34,7 +34,7 @@ struct MultiChange {
     {
     }
 
-    bool inProgress() const
+    Q_REQUIRED_RESULT bool inProgress() const
     {
         return parent.isValid() && !children.isEmpty();
     }
@@ -150,10 +150,7 @@ CalendarUtils::CalendarUtils(const Akonadi::ETMCalendar::Ptr &calendar, QObject
     Q_ASSERT(calendar);
 }
 
-CalendarUtils::~CalendarUtils()
-{
-    delete d_ptr;
-}
+CalendarUtils::~CalendarUtils() = default;
 
 Akonadi::ETMCalendar::Ptr CalendarUtils::calendar() const
 {
